@@ -11,7 +11,7 @@
 ##' If the trial is randomized in incomplete blocks design, `repl` will be a string vector
 ##' containing the name of the columns that correspond to the replicate and block effects on
 ##' the first and second positions, respectively (`c(replicate, block)`).
-##' If the data does not have replicates, `repl` will be `NULL`.
+##' If the data does not have replicates, `repl` must be `NULL`.
 ##' @param trait A string. The analysed variable. Currently, only single-trait models are fitted.
 ##' @param reg A string or NULL. The name of the column that contain information on
 ##' regions or mega-environments. `NULL` (default) if not applicable.
@@ -19,7 +19,7 @@
 ##' years (or seasons). `NULL` (default) if not applicable.
 ##' @param res.het Should the model consider heterogeneous residual variances?
 ##' Defaults for `FALSE`. If `TRUE`, the model will estimate one
-##' residual variance per location (or environmnet). If `repl = NULL`, `res.het` must be `TRUE`.
+##' residual variance per location (or environmnet).
 ##' @inheritParams rstan::sampling
 ##'
 ##' @inheritSection rstan::sampling Methods
@@ -33,7 +33,7 @@
 ##' \deqn{y = \mu + g + l + \varepsilon}
 ##' Where \eqn{y} is the phenotype, \eqn{\mu} is the intercept, \eqn{g} is the genotypic
 ##' effect, \eqn{l} is the location (or environment) effect, and \eqn{\varepsilon} is
-##' the residue (which contains the genotype-by-location interaction, in this case).
+##' the error (which contains the genotype-by-location interaction, in this case).
 ##'
 ##' \item{Randomized complete blocks design} : fitted when `repl` is a single string.
 ##' It will fit different models depending if `reg` and `year` are `NULL`:
@@ -107,7 +107,7 @@ bayes_met = function(data, gen, loc, repl, trait, reg = NULL, year = NULL,
                      init = 'random', verbose = FALSE,
                      algorithm = c("NUTS", "HMC", "Fixed_param"),
                      control = NULL, include = TRUE, show_messages = TRUE, ...)
-  {
+{
 
   requireNamespace('rstan')
 
@@ -117,7 +117,7 @@ bayes_met = function(data, gen, loc, repl, trait, reg = NULL, year = NULL,
   stopifnot("loc is not in the data" = loc %in% colnames(data))
   stopifnot("Please, specify the trait" = trait %in% colnames(data))
   if(is.null(repl)){
-    stopifnot("By default, a model with no replicates can only be fitted with heterogeneous residual variances (res.het = TRUE)" = res.het)
+    # stopifnot("By default, a model with no replicates can only be fitted with heterogeneous residual variances (res.het = TRUE)" = res.het)
     stopifnot("'reg' must be NULL to fit an entry-mean model (G + L + error)" = is.null(reg))
     stopifnot("'year' must be NULL to fit an entry-mean model (G + L + error)" = is.null(year))
   }
@@ -126,7 +126,7 @@ bayes_met = function(data, gen, loc, repl, trait, reg = NULL, year = NULL,
   if(!all(grepl('[A-Za-z]', data[, loc]))){data[,loc] = paste("E", data[,loc], sep = "_")}
 
   if(res.het){
-  # Heterogeneous residual variances -----------------
+    # Heterogeneous residual variances -----------------
     if(is.null(year)){
       # No year effect --------------------------
       if(is.null(reg)){
@@ -158,7 +158,7 @@ bayes_met = function(data, gen, loc, repl, trait, reg = NULL, year = NULL,
 
           # stan_df_comp = rstan::stan_model(model_code = stan_df, model_name = "BayesMET: entry-mean")
 
-          Model = rstan::sampling(object = stanmodels$entrymean, data = df_stan,iter = iter,
+          Model = rstan::sampling(object = stanmodels$entrymean1, data = df_stan,iter = iter,
                                   cores = cores, chains = chains, pars = pars,
                                   warmup = warmup, thin = thin, seed = seed,
                                   init = init, verbose = verbose,
@@ -315,15 +315,15 @@ bayes_met = function(data, gen, loc, repl, trait, reg = NULL, year = NULL,
       }
 
     }else # With year effect --------------------------
-      {
+    {
       stopifnot("year is not in the data" = year %in% colnames(data))
 
-        if(!all(grepl('[A-Za-z]', data[, year]))){data[,year] = paste("Y", data[, year], sep = "_")}
+      if(!all(grepl('[A-Za-z]', data[, year]))){data[,year] = paste("Y", data[, year], sep = "_")}
 
       if(is.null(reg)) # No region effect ---------------------------
-        {
+      {
         if(length(repl) == 1) # RCBD ------------------------
-          {
+        {
           stopifnot("repl is not in the data" = repl %in% colnames(data))
           data[,gen] = as.factor(data[,gen])
           data[,loc] = as.factor(data[,loc])
@@ -359,7 +359,7 @@ bayes_met = function(data, gen, loc, repl, trait, reg = NULL, year = NULL,
           attr(Model, 'modmean') = FALSE
 
         }else if(length(repl) == 2) # Incomplete blocks ------------------------
-          {
+        {
           stopifnot("repl are not in the data" = repl %in% colnames(data))
           data[,gen] = as.factor(data[,gen])
           data[,loc] = as.factor(data[,loc])
@@ -399,13 +399,13 @@ bayes_met = function(data, gen, loc, repl, trait, reg = NULL, year = NULL,
 
         }
       }else # With region effect ------------------------
-        {
-          stopifnot("reg is not in the data" = reg %in% colnames(data))
+      {
+        stopifnot("reg is not in the data" = reg %in% colnames(data))
 
-          if(!all(grepl('[A-Za-z]', data[, reg]))){data[,reg] = paste("R", data[,reg], sep = "_")}
+        if(!all(grepl('[A-Za-z]', data[, reg]))){data[,reg] = paste("R", data[,reg], sep = "_")}
 
         if(length(repl) == 1) # RCB -------------------------
-          {
+        {
           data[,gen] = as.factor(data[,gen])
           data[,reg] = as.factor(data[,reg])
           data[,loc] = as.factor(data[,loc])
@@ -446,7 +446,7 @@ bayes_met = function(data, gen, loc, repl, trait, reg = NULL, year = NULL,
           attr(Model, 'modmean') = FALSE
 
         }else if(length(repl) == 2) # incomplete blocks ------------------------
-          {
+        {
           stopifnot("repl is are not in the data" = repl %in% colnames(data))
           data[,gen] = as.factor(data[,gen])
           data[,reg] = as.factor(data[,reg])
@@ -493,152 +493,187 @@ bayes_met = function(data, gen, loc, repl, trait, reg = NULL, year = NULL,
       }
     }
 
-}else # Homogeneous variances ------------------------------
+  }else # Homogeneous variances ------------------------------
   {
-  if(is.null(year)) # No year effect ------------------------
+    if(is.null(year)) # No year effect ------------------------
     {
-    if(is.null(reg)) # No region information -----------------------------
+      if(is.null(reg)) # No region information -----------------------------
       {
-      if(length(repl) == 1) # RCB ---------------------
+        if(is.null(repl)){
+          # Only means --------------------------------
+          data[,gen] = as.factor(data[,gen])
+          data[,loc] = as.factor(data[,loc])
+          n = nrow(data)
+          Z3 = model.matrix(~-1 + data[,gen])
+          Z4 = model.matrix(~-1 + data[,loc])
+          # Z5 = model.matrix(~-1 + data[,gen]:data[,loc])
+          p3 <- ncol(Z3)
+          p4 <- ncol(Z4)
+          # p5 <- ncol(Z5)
+          y = data[,trait]
+          index = rep(1:nlevels(data[,loc]), times = as.numeric(table(data[,loc])))
+          phi = max(y) * 10
+          df_stan = list(n = n,
+                         p3 = p3,
+                         p4 = p4,
+                         # p5 = p5,
+                         Z3 = Z3,
+                         Z4 = Z4,
+                         #Z5 = Z5,
+                         index = index,
+                         y = y,
+                         phi = phi)
+
+          # stan_df_comp = rstan::stan_model(model_code = stan_df, model_name = "BayesMET: entry-mean")
+
+          Model = rstan::sampling(object = stanmodels$entrymean2, data = df_stan, iter = iter,
+                                  cores = cores, chains = chains, pars = pars,
+                                  warmup = warmup, thin = thin, seed = seed,
+                                  init = init, verbose = verbose,
+                                  algorithm = algorithm, control = control,
+                                  include = include, show_messages = show_messages, ...)
+          attr(Model, 'modmean') = TRUE
+
+        }else if(length(repl) == 1) # RCB ---------------------
         {
-        data[,gen] = as.factor(data[,gen])
-        data[,loc] = as.factor(data[,loc])
-        data[,repl] = as.factor(data[,repl])
-        n = nrow(data)
-        Z1 = model.matrix(~-1 + data[,repl]:data[,loc])
-        Z3 = model.matrix(~-1 + data[,gen])
-        Z4 = model.matrix(~-1 + data[,loc])
-        Z5 = model.matrix(~-1 + data[,gen]:data[,loc])
-        p1 <- ncol(Z1)
-        p3 <- ncol(Z3)
-        p4 <- ncol(Z4)
-        p5 <- ncol(Z5)
-        y = data[,trait]
-        phi = max(y) * 10
-        df_stan = list(n = n, p1 = p1, p3 = p3, p4 = p4,
-                       p5 = p5, Z1 = Z1, Z3 = Z3, Z4 = Z4,Z5 = Z5, y = y, phi = phi)
+          data[,gen] = as.factor(data[,gen])
+          data[,loc] = as.factor(data[,loc])
+          data[,repl] = as.factor(data[,repl])
+          n = nrow(data)
+          Z1 = model.matrix(~-1 + data[,repl]:data[,loc])
+          Z3 = model.matrix(~-1 + data[,gen])
+          Z4 = model.matrix(~-1 + data[,loc])
+          Z5 = model.matrix(~-1 + data[,gen]:data[,loc])
+          p1 <- ncol(Z1)
+          p3 <- ncol(Z3)
+          p4 <- ncol(Z4)
+          p5 <- ncol(Z5)
+          y = data[,trait]
+          phi = max(y) * 10
+          df_stan = list(n = n, p1 = p1, p3 = p3, p4 = p4,
+                         p5 = p5, Z1 = Z1, Z3 = Z3, Z4 = Z4,Z5 = Z5, y = y, phi = phi)
 
-        # stan_df_comp = rstan::stan_model(model_code = stan_df, model_name = "BayesMET")
+          # stan_df_comp = rstan::stan_model(model_code = stan_df, model_name = "BayesMET")
 
-        Model = rstan::sampling(object = stanmodels$RCBD5, data = df_stan, iter = iter,
-                                cores = cores, chains = chains, pars = pars,
-                                warmup = warmup, thin = thin, seed = seed,
-                                init = init, verbose = verbose,
-                                algorithm = algorithm, control = control,
-                                include = include, show_messages = show_messages,...)
-        attr(Model, 'modmean') = FALSE
+          Model = rstan::sampling(object = stanmodels$RCBD5, data = df_stan, iter = iter,
+                                  cores = cores, chains = chains, pars = pars,
+                                  warmup = warmup, thin = thin, seed = seed,
+                                  init = init, verbose = verbose,
+                                  algorithm = algorithm, control = control,
+                                  include = include, show_messages = show_messages,...)
+          attr(Model, 'modmean') = FALSE
 
-      }else if(length(repl) == 2) # incomplete blocks --------------------------
+        }else if(length(repl) == 2) # incomplete blocks --------------------------
         {
-        data[,gen] = as.factor(data[,gen])
-        data[,loc] = as.factor(data[,loc])
-        data[,repl[1]] = as.factor(data[,repl[1]])
-        data[,repl[2]] = as.factor(data[,repl[2]])
-        n = nrow(data)
-        Z1 = model.matrix(~-1 + data[,repl[1]]:data[,loc])
-        Z2 = model.matrix(~-1 + data[,repl[2]]:data[,loc])
-        Z3 = model.matrix(~-1 + data[,gen])
-        Z4 = model.matrix(~-1 + data[,loc])
-        Z5 = model.matrix(~-1 + data[,gen]:data[,loc])
-        p1 <- ncol(Z1)
-        p2 <- ncol(Z2)
-        p3 <- ncol(Z3)
-        p4 <- ncol(Z4)
-        p5 <- ncol(Z5)
-        y = data[,trait]
-        phi = max(y) * 10
-        df_stan = list(n = n, p1 = p1, p2 = p2, p3 = p3, p4 = p4, p5 = p5,
-                       Z1 = Z1, Z2 = Z2, Z3 = Z3, Z4 = Z4, Z5 = Z5, y = y, phi = phi)
+          data[,gen] = as.factor(data[,gen])
+          data[,loc] = as.factor(data[,loc])
+          data[,repl[1]] = as.factor(data[,repl[1]])
+          data[,repl[2]] = as.factor(data[,repl[2]])
+          n = nrow(data)
+          Z1 = model.matrix(~-1 + data[,repl[1]]:data[,loc])
+          Z2 = model.matrix(~-1 + data[,repl[2]]:data[,loc])
+          Z3 = model.matrix(~-1 + data[,gen])
+          Z4 = model.matrix(~-1 + data[,loc])
+          Z5 = model.matrix(~-1 + data[,gen]:data[,loc])
+          p1 <- ncol(Z1)
+          p2 <- ncol(Z2)
+          p3 <- ncol(Z3)
+          p4 <- ncol(Z4)
+          p5 <- ncol(Z5)
+          y = data[,trait]
+          phi = max(y) * 10
+          df_stan = list(n = n, p1 = p1, p2 = p2, p3 = p3, p4 = p4, p5 = p5,
+                         Z1 = Z1, Z2 = Z2, Z3 = Z3, Z4 = Z4, Z5 = Z5, y = y, phi = phi)
 
-        # stan_df_comp = rstan::stan_model(model_code = stan_df, model_name = "BayesMET")
+          # stan_df_comp = rstan::stan_model(model_code = stan_df, model_name = "BayesMET")
 
-        Model = rstan::sampling(object = stanmodels$IBD5, data = df_stan,iter = iter,
-                                cores = cores, chains = chains, pars = pars,
-                                warmup = warmup, thin = thin, seed = seed,
-                                init = init, verbose = verbose,
-                                algorithm = algorithm, control = control,
-                                include = include, show_messages = show_messages, ...)
-        attr(Model, 'modmean') = FALSE
+          Model = rstan::sampling(object = stanmodels$IBD5, data = df_stan,iter = iter,
+                                  cores = cores, chains = chains, pars = pars,
+                                  warmup = warmup, thin = thin, seed = seed,
+                                  init = init, verbose = verbose,
+                                  algorithm = algorithm, control = control,
+                                  include = include, show_messages = show_messages, ...)
+          attr(Model, 'modmean') = FALSE
 
-      }
-    }else # With region information -------------------------
+        }
+      }else # With region information -------------------------
       {
         if(!all(grepl('[A-Za-z]', data[, reg]))){data[,reg] = paste("R", data[,reg], sep = "_")}
-      if(length(repl) == 1) # RCDB --------------------
+        if(length(repl) == 1) # RCDB --------------------
         {
-        data[,gen] = as.factor(data[,gen])
-        data[,reg] = as.factor(data[,reg])
-        data[,loc] = as.factor(data[,loc])
-        data[,repl] = as.factor(data[,repl])
-        n = nrow(data)
-        Z1 = model.matrix(~-1 + data[,repl]:data[,loc])
-        Z3 = model.matrix(~-1 + data[,gen])
-        Z4 = model.matrix(~-1 + data[,loc])
-        Z5 = model.matrix(~-1 + data[,gen]:data[,loc])
-        Z6 = model.matrix(~-1 + data[,reg])
-        Z7 = model.matrix(~-1 + data[,gen]:data[,reg])
-        p1 <- ncol(Z1)
-        p3 <- ncol(Z3)
-        p4 <- ncol(Z4)
-        p5 <- ncol(Z5)
-        p6 <- ncol(Z6)
-        p7 <- ncol(Z7)
-        y = data[,trait]
-        phi = max(y) * 10
-        df_stan = list(n = n, p1 = p1, p3 = p3, p4 = p4, p5 = p5, p6 = p6,
-                       p7 = p7, Z1 = Z1, Z3 = Z3, Z4 = Z4, Z5 = Z5, Z6 = Z6,
-                       Z7 = Z7, y = y, phi = phi)
+          data[,gen] = as.factor(data[,gen])
+          data[,reg] = as.factor(data[,reg])
+          data[,loc] = as.factor(data[,loc])
+          data[,repl] = as.factor(data[,repl])
+          n = nrow(data)
+          Z1 = model.matrix(~-1 + data[,repl]:data[,loc])
+          Z3 = model.matrix(~-1 + data[,gen])
+          Z4 = model.matrix(~-1 + data[,loc])
+          Z5 = model.matrix(~-1 + data[,gen]:data[,loc])
+          Z6 = model.matrix(~-1 + data[,reg])
+          Z7 = model.matrix(~-1 + data[,gen]:data[,reg])
+          p1 <- ncol(Z1)
+          p3 <- ncol(Z3)
+          p4 <- ncol(Z4)
+          p5 <- ncol(Z5)
+          p6 <- ncol(Z6)
+          p7 <- ncol(Z7)
+          y = data[,trait]
+          phi = max(y) * 10
+          df_stan = list(n = n, p1 = p1, p3 = p3, p4 = p4, p5 = p5, p6 = p6,
+                         p7 = p7, Z1 = Z1, Z3 = Z3, Z4 = Z4, Z5 = Z5, Z6 = Z6,
+                         Z7 = Z7, y = y, phi = phi)
 
-        # stan_df_comp = rstan::stan_model(model_code = stan_df, model_name = "BayesMET")
+          # stan_df_comp = rstan::stan_model(model_code = stan_df, model_name = "BayesMET")
 
-        Model = rstan::sampling(object = stanmodels$RCBD6, data = df_stan,iter = iter,
-                                cores = cores, chains = chains, pars = pars,
-                                warmup = warmup, thin = thin, seed = seed,
-                                init = init, verbose = verbose,
-                                algorithm = algorithm, control = control,
-                                include = include, show_messages = show_messages, ...)
-        attr(Model, 'modmean') = FALSE
+          Model = rstan::sampling(object = stanmodels$RCBD6, data = df_stan,iter = iter,
+                                  cores = cores, chains = chains, pars = pars,
+                                  warmup = warmup, thin = thin, seed = seed,
+                                  init = init, verbose = verbose,
+                                  algorithm = algorithm, control = control,
+                                  include = include, show_messages = show_messages, ...)
+          attr(Model, 'modmean') = FALSE
 
-      }else if(length(repl) == 2) # Incomplete blocks --------------------------
+        }else if(length(repl) == 2) # Incomplete blocks --------------------------
         {
-        data[,gen] = as.factor(data[,gen])
-        data[,reg] = as.factor(data[,reg])
-        data[,loc] = as.factor(data[,loc])
-        data[,repl[1]] = as.factor(data[,repl[1]])
-        data[,repl[2]] = as.factor(data[,repl[2]])
-        n = nrow(data)
-        Z1 = model.matrix(~-1 + data[,repl[1]]:data[,loc])
-        Z2 = model.matrix(~-1 + data[,repl[2]]:data[,loc])
-        Z3 = model.matrix(~-1 + data[,gen])
-        Z4 = model.matrix(~-1 + data[,loc])
-        Z5 = model.matrix(~-1 + data[,gen]:data[,loc])
-        Z6 = model.matrix(~-1 + data[,reg])
-        Z7 = model.matrix(~-1 + data[,gen]:data[,reg])
-        p1 <- ncol(Z1)
-        p2 <- ncol(Z2)
-        p3 <- ncol(Z3)
-        p4 <- ncol(Z4)
-        p5 <- ncol(Z5)
-        p6 <- ncol(Z6)
-        p7 <- ncol(Z7)
-        y = data[,trait]
-        phi = max(y) * 10
-        df_stan = list(n = n, p1 = p1, p2 = p2, p3 = p3, p4 = p4, p5 = p5, p6 = p6,
-                       p7 = p7, Z1 = Z1, Z2 = Z2, Z3 = Z3, Z4 = Z4, Z5 = Z5, Z6 = Z6,
-                       Z7 = Z7, y = y, phi = phi)
+          data[,gen] = as.factor(data[,gen])
+          data[,reg] = as.factor(data[,reg])
+          data[,loc] = as.factor(data[,loc])
+          data[,repl[1]] = as.factor(data[,repl[1]])
+          data[,repl[2]] = as.factor(data[,repl[2]])
+          n = nrow(data)
+          Z1 = model.matrix(~-1 + data[,repl[1]]:data[,loc])
+          Z2 = model.matrix(~-1 + data[,repl[2]]:data[,loc])
+          Z3 = model.matrix(~-1 + data[,gen])
+          Z4 = model.matrix(~-1 + data[,loc])
+          Z5 = model.matrix(~-1 + data[,gen]:data[,loc])
+          Z6 = model.matrix(~-1 + data[,reg])
+          Z7 = model.matrix(~-1 + data[,gen]:data[,reg])
+          p1 <- ncol(Z1)
+          p2 <- ncol(Z2)
+          p3 <- ncol(Z3)
+          p4 <- ncol(Z4)
+          p5 <- ncol(Z5)
+          p6 <- ncol(Z6)
+          p7 <- ncol(Z7)
+          y = data[,trait]
+          phi = max(y) * 10
+          df_stan = list(n = n, p1 = p1, p2 = p2, p3 = p3, p4 = p4, p5 = p5, p6 = p6,
+                         p7 = p7, Z1 = Z1, Z2 = Z2, Z3 = Z3, Z4 = Z4, Z5 = Z5, Z6 = Z6,
+                         Z7 = Z7, y = y, phi = phi)
 
-        # stan_df_comp = rstan::stan_model(model_code = stan_df, model_name = "BayesMET")
+          # stan_df_comp = rstan::stan_model(model_code = stan_df, model_name = "BayesMET")
 
-        Model = rstan::sampling(object = stanmodels$IBD6, data = df_stan,iter = iter,
-                                cores = cores, chains = chains, pars = pars,
-                                warmup = warmup, thin = thin, seed = seed,
-                                init = init, verbose = verbose,
-                                algorithm = algorithm, control = control,
-                                include = include, show_messages = show_messages, ...)
-        attr(Model, 'modmean') = FALSE
+          Model = rstan::sampling(object = stanmodels$IBD6, data = df_stan,iter = iter,
+                                  cores = cores, chains = chains, pars = pars,
+                                  warmup = warmup, thin = thin, seed = seed,
+                                  init = init, verbose = verbose,
+                                  algorithm = algorithm, control = control,
+                                  include = include, show_messages = show_messages, ...)
+          attr(Model, 'modmean') = FALSE
+        }
       }
-    }
-  }else # With year effect ------------------
+    }else # With year effect ------------------
     {
       if(!all(grepl('[A-Za-z]', data[, year]))){data[,year] = paste("Y", data[, year], sep = "_")}
 
@@ -803,7 +838,7 @@ bayes_met = function(data, gen, loc, repl, trait, reg = NULL, year = NULL,
           attr(Model, 'modmean') = FALSE
         }
       }
-  }
+    }
   }
 
   attr(Model, "declared_eff") = data.frame(trait = trait, gen = gen,
